; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10

;--------|Ai Activation|------------------------------------------
[Command] 
name = "cpu01" 
command = F, D,DF, F,x,x,x,x,x 
time = 1 

[Command] 
name = "cpu02" 
command = F, D,DF, F,x,x,x,x,y 
time = 1 

[Command] 
name = "cpu03" 
command = F,x,x,x,y,x 
time = 1 

[Command] 
name = "cpu04" 
command = F, D,DF, F,x,x,y,x,x 
time = 1 

[Command] 
name = "cpu05" 
command = F, D,DF, F,x,y,x,x,x 
time = 1 

[Command] 
name = "cpu06" 
command = F, D,DF, F,y,x,x,x,x 
time = 1 

[Command] 
name = "cpu07" 
command = F, D,DF, F,y,x,x,x,y 
time = 1 

[Command] 
name = "cpu08" 
command = F, D,DF, F,y,x,x,y,x 
time = 1 

[Command] 
name = "cpu09" 
command = F, D,DF, F,y,x,y,x,x 
time = 1 

[Command] 
name = "cpu10" 
command = F, D,DF, F,y,y,x,x,x 
time = 1

[Command] 
name = "cpu11" 
command = F, D,DF, F,a,x,x,x,x 
time = 1 

[Command] 
name = "cpu12" 
command = F, D,DF, F,a,x,x,x,y 
time = 1 

[Command] 
name = "cpu13" 
command = F, D,DF, F,a,x,x,y,x 
time = 1 

[Command] 
name = "cpu14" 
command = F, D,DF, F,a,x,y,x,x 
time = 1 

[Command] 
name = "cpu15" 
command = F, D,DF, F,a,y,x,x,x 
time = 1 

[Command] 
name = "cpu16" 
command = F, D,DF, F,y,x,x,x,a 
time = 1 

[Command]
name = "cpu17" 
command = F, D,DF, F,y,x,x,a,x 
time = 1 

[Command] 
name = "cpu18" 
command = F, D,DF, F,y,x,a,x,x 
time = 1 

[Command] 
name = "cpu19" 
command = F, D,DF, F,y,a,x,x,x 
time = 1 

[Command] 
name = "cpu20" 
command = F, D,DF, F,a,a,x,x,x 
time = 1

[Command] 
name = "cpu21" 
command = F, D,DF, F,b,x,x,x,x 
time = 1 

[Command] 
name = "cpu22" 
command = F, D,DF, F,b,x,x,x,y 
time = 1 

[Command] 
name = "cpu23" 
command = F, D,DF, F,b,x,x,y,x 
time = 1 

[Command] 
name = "cpu24" 
command = F, D,DF, F,b,x,y,x,x 
time = 1 

[Command] 
name = "cpu25" 
command = F, D,DF, F,b,y,x,x,x 
time = 1 

[Command] 
name = "cpu26" 
command = F, D,DF, F,y,x,x,x,b 
time = 1 

[Command] 
name = "cpu27" 
command = F, D,DF, F,y,x,x,b,x 
time = 1 

[Command] 
name = "cpu28" 
command = F, D,DF, F,y,x,b,x,x 
time = 1 

[Command] 
name = "cpu29" 
command = F, D,DF, F,y,b,x,x,x 
time = 1 

[Command] 
name = "cpu30" 
command = F, D,DF, F,b,b,x,x,x 
time = 1


[Command] 
name = "cpu31" 
command = F, D,DF, F,b,x,x,x,x 
time = 1 

[Command] 
name = "cpu32" 
command = F, D,DF, F,b,x,x,x,y 
time = 1 

[Command] 
name = "cpu33" 
command = F, D,DF, F,b,x,x,y,x 
time = 1 

[Command] 
name = "cpu34" 
command = F, D,DF, F,b,x,y,x,x 
time = 1 

[Command] 
name = "cpu35" 
command = F, D,DF, F,b,y,x,x,x 
time = 1 

[Command] 
name = "cpu36" 
command = F, D,DF, F,y,x,x,x,b 
time = 1 

[Command] 
name = "cpu37" 
command = F, D,DF, F,y,x,x,b,x 
time = 1 

[Command] 
name = "cpu38" 
command = F, D,DF, F,y,x,b,x,x 
time = 1 

[Command] 
name = "cpu39" 
command = F, D,DF, F,y,b,x,x,x 
time = 1 

[Command] 
name = "cpu40" 
command = F, D,DF, F,b,b,x,x,x 
time = 1


[Command] 
name = "cpu41" 
command = F, D,DF, F,b,x,x,x,x 
time = 1 

[Command] 
name = "cpu42" 
command = F, D,DF, F,b,x,x,x,y 
time = 1 

[Command] 
name = "cpu43" 
command = F, D,DF, F,b,x,x,y,x 
time = 1 

[Command] 
name = "cpu44" 
command = F, D,DF, F,b,x,y,x,x 
time = 1 

[Command] 
name = "cpu45" 
command = F, D,DF, F,b,y,x,x,x 
time = 1 

[Command] 
name = "cpu46" 
command = F, D,DF, F,y,x,x,x,b 
time = 1 

[Command] 
name = "cpu47" 
command = F, D,DF, F,y,x,x,b,x 
time = 1 

[Command] 
name = "cpu48" 
command = F, D,DF, F,y,x,b,x,x 
time = 1 

[Command] 
name = "cpu49" 
command = F, D,DF, F,y,b,x,x,x 
time = 1 

[Command] 
name = "cpu50" 
command = F, D,DF, F,b,b,x,x,x 
time = 1

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------


[Command]
name = "Lillith Team Up Attack"
command = ~F, D, B, a


[Command]
name = "Super Wing Slash"
command = ~F, D, B, b

[Command]
name = "Death Blade"
command = ~F, D, B, c



;-| Special Motions |------------------------------------------------------



;Fire Bat Level 1
[Command]
name = "QCF_x"
command = ~D, DF, F, x

;Fire Bat Level 2
[Command]
name = "QCF_y"
command = ~D, DF, F, y

;Fire Bat Level 3
[Command]
name = "QCF_z"
command = ~D, DF, F, z

;Shadow Blade level 1
[Command]
name = "QCF_a"
command = ~D, DF, F, a

;Shadow Blade level 2
[Command]
name = "QCF_b"
command = ~D, DF, F, b

;Shadow Blade level 3
[Command]
name = "QCF_c"
command = ~D, DF, F, c

;Spinning Wing Slash 1
[Command]
name = "QCB_x"
command = ~D, DB, B, x

;Spinning Wing Slash 2
[Command]
name = "QCB_y"
command = ~D, DB, B, y

;Spinning Wing Slash 3
[Command]
name = "QCB_z"
command = ~D, DB, B, z


; Nurse WheelChair Push, 300
[Command]
name = "FFx"
command = F, F, x

;Maid Mop Push, 310
[Command]
name = "FFy"
command = F, F, y


[Command]
name = "Oiuchi"
command = $U,a

[Command]
name = "Rolling Crush"
command = B,F,a

[Command]
name = "Mega Crush"
command = B,F,b


[Command]
name = "Easy Reversal"
command = B,F,c


[Command]
name = "Special Reversal"
command = /B,c


[Command]
name = "Super Jump"
command = D,$U



;----|Combo Motions|---------------------------------------
;P,P,P,P =   Stand Punch, Nurse hit w/Crutch, Nurse hit w/Stand, Nurse WheelChair Push
[Command]
name = "Flash Combo 1"
command = x,x,x,x  

;P,P,P,K =   Stand Punch, Nurse hit w/Crutch, Nurse hit w/Stand, Maid Pan SmashFC

[Command]
name = "Flash Combo 2"
command = x,x,x,y  

;P,P,K,K =   Stand Punch, Nurse hit w/Crutch, Maid Mop PushFC, Maid Pan SmashFC
[Command]
name = "Flash Combo 3"
command = x,x,y,y  

;P,K,K,K =   Stand Punch, Waitress Hit w/Tray, Waitress Spill Tray, Waitress Hit w/Cash Register
[Command]
name = "Flash Combo 4"
command = x,y,y,y 

;P,P,K,P =   Stand Punch, Nurse hit w/Crutch, Maid Mop PushFC , Nurse WheelChair Push
[Command]
name = "Flash Combo 5"
command = x,x,y,x

;P,K,P,P =   Stand Punch, Waitress Hit w/Tray, Kimono Hit w/Fan, Grab To FireWork
[Command]
name = "Flash Combo 6"
command = x,y,x,x

;P,K,K,P =   Stand Punch, Waitress Hit w/Tray, Waitress Spill Tray,  Grab To FireWork

[Command]
name = "Flash Combo 7"
command = x,y,y,x

;P,K,P,K =   Stand Punch, Waitress Hit w/Tray, Kimono Hit w/Fan, Waitress Hit w/Cash Register
[Command]
name = "Flash Combo 8"
command = x,y,x,y

;----|Throw Motions|---------------------------------------

;BodySlam
[Command]
name = "Stand Throw"  ;while standing
command = x+y


;Flying Air Slam
[Command]
name = "Air Throw" ; in the air
command = x+y

;Air Slam, while standing
[Command]
name = "special throw"
command = ~B,F,B,b

[Command]
name = "FireWork"
command = ~B,F,B,x


;----|Basic Motions|---------------------------------------



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---|Hold Buttons|------------------------
[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdc"
command = /c
time = 1


[Command]
name = "holdx"
command = /x
time = 1


[Command]
name = "holdy"
command = /y
time = 1


[Command]
name = "holds"
command = /s
time = 1

;---|Relase Buttons|------------------------


;---|Press then Release no other key in between|------------------


;--------------

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]


;===========================================================================
;This is not a move, but it sets up var(3) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(17) = 0

[State -1, Move Cancel condition Reset]
type = VarSet
trigger1 = 1
var(51) = 0


[State -1, Move Miss Reset]
type = VarSet
trigger1 = 1
var(9) = 0


[State -1, Combo condition Check]
type = VarSet
triggerall = statetype != A
triggerall = movecontact
trigger1 = stateno = 200
trigger2 = stateno = 230
trigger3 = stateno = 400
;trigger4 = stateno = 430 ;morrigan
var(17) = 1




[State -1, Combo condition Check]
type = VarSet
triggerall = statetype != A
triggerall = movecontact
trigger1 = stateno = 240 || stateno = 210
trigger2 = stateno = 440 || stateno = 430
trigger3 = stateno = 410
var(17) = 2




[State -1, Combo condition Check]
type = VarSet
triggerall = statetype != A
triggerall = movecontact
trigger1 = stateno = 300
trigger2 = stateno = 310
var(17) = 3




[State -1, Combo condition Check]
type = VarSet
triggerall = statetype = A
triggerall = movecontact
trigger1 = stateno = 600
trigger2 = stateno = 630
var(17) = 5


[State -1, Combo condition Check]
type = VarSet
triggerall = statetype = A
triggerall = movecontact
trigger1 = stateno = 610
trigger2 = stateno = 640
var(17) = 6



[State -1, Combo condition Check]
type = null;VarSet
triggerall = statetype = A
triggerall = movecontact
trigger1 = stateno = 620
trigger2 = stateno = 720
var(17) = 7



[State -1, Normal to Special to Hypers]
type = VarSet
trigger1 = stateno = [200,799]
trigger2 = stateno = [8016,8018]
var(51) = 1


[State -1, Normal to Special to Hypers]
type = VarSet
trigger1 = stateno = [2000,2900]
;trigger2 = stateno = [1450,1700]
var(51) = 2




;-------------------
; Get modified Enemy Y dist
[State -1]
type = VarSet
trigger1 = 1;var(59)
var(8) = floor(P2Dist Y - (abs(EnemyNear, const(size.mid.pos.y)) - abs(const(size.mid.pos.y))))


;-------------------
; Get modified Enemy Y dist
[State -1]
type = null;VarSet
trigger1 = 1;var(59)
var(8) = floor(P2BodyDist Y - (abs(EnemyNear, const(size.head.pos.y)) - abs(const(size.head.pos.y))))

;-------------------
[State -1]
type = VarSet
trigger1 = 1;var(59)
var(7) = abs(enemynear,const(size.head.pos.y))


;===========================================================================
;===========================================================================
;------|AI Moves|-----------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu01"
trigger2 = command = "cpu02"
trigger3 = command = "cpu03"
trigger4 = command = "cpu04"
trigger5 = command = "cpu05"
trigger6 = command = "cpu06"
trigger7 = command = "cpu07"
trigger8 = command = "cpu08"
trigger9 = command = "cpu09"
trigger10 = command = "cpu10"
var(59) = 1
;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu11"
trigger2 = command = "cpu12"
trigger3 = command = "cpu13"
trigger4 = command = "cpu14"
trigger5 = command = "cpu15"
trigger6 = command = "cpu16"
trigger7 = command = "cpu17"
trigger8 = command = "cpu18"
trigger9 = command = "cpu19"
trigger10 = command = "cpu20"
var(59) = 1

;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu21"
trigger2 = command = "cpu22"
trigger3 = command = "cpu23"
trigger4 = command = "cpu24"
trigger5 = command = "cpu25"
trigger6 = command = "cpu26"
trigger7 = command = "cpu27"
trigger8 = command = "cpu28"
trigger9 = command = "cpu29"
trigger10 = command = "cpu30"
var(59) = 1


;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu31"
trigger2 = command = "cpu32"
trigger3 = command = "cpu33"
trigger4 = command = "cpu34"
trigger5 = command = "cpu35"
trigger6 = command = "cpu36"
trigger7 = command = "cpu37"
trigger8 = command = "cpu38"
trigger9 = command = "cpu39"
trigger10 = command = "cpu40"
var(59) = 1

;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu41"
trigger2 = command = "cpu42"
trigger3 = command = "cpu43"
trigger4 = command = "cpu44"
trigger5 = command = "cpu45"
trigger6 = command = "cpu46"
trigger7 = command = "cpu47"
trigger8 = command = "cpu48"
trigger9 = command = "cpu49"
trigger10 = command = "cpu50"
var(59) = 1
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------

[State -1,AI]
type = Varset
trigger1 = !Var(56)
var(56) = 1

;------------------------------------------------------------------
[State -1,AI]
type = Varset
trigger1 = var(59) && var(56) < 1
var(59) = 0 + random < 100 

;-----------------------------------------------------------------------------
;max hit combo each type
[State -1]
type = varset
trigger1 = var(36) != 1 
trigger2 = var(56) != 4
var(36) = 1

;max hit combo each type
[State -1]
type = varset
trigger1 = var(56) = 4
trigger1 = var(36) != 4
var(36) = 4
;---------------------------------------------------------------------------


;------------------------------------------------------------------

[State -1,AI]
type = Varset
triggerall = var(59)
triggerall = time = 1
trigger1 = p2life <= 0
trigger2 = life <= 0
var(59) = 0


[state -1,Mode Set]
type = VarSet
triggerall = !var(59)
trigger1 = command = "holds"
trigger1 = command = "x" && command = "y"
var(56) = 0


[state -1,Mode Set]
type = VarSet
triggerall = !var(59)
trigger1 = command = "holds"
trigger1 = command = "a" && command = "b"
var(56) = 1


[state -1,Mode Set]
type = VarSet
triggerall = !var(59)
trigger1 = command = "holds"
trigger1 = command = "z" && command = "c"
var(56) = 4

;===========================================================================
;===========================================================================
;------|AI Moves|-----------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu01"
trigger2 = command = "cpu02"
trigger3 = command = "cpu03"
trigger4 = command = "cpu04"
trigger5 = command = "cpu05"
trigger6 = command = "cpu06"
trigger7 = command = "cpu07"
trigger8 = command = "cpu08"
trigger9 = command = "cpu09"
trigger10 = command = "cpu10"
var(59) = 1
;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu11"
trigger2 = command = "cpu12"
trigger3 = command = "cpu13"
trigger4 = command = "cpu14"
trigger5 = command = "cpu15"
trigger6 = command = "cpu16"
trigger7 = command = "cpu17"
trigger8 = command = "cpu18"
trigger9 = command = "cpu19"
trigger10 = command = "cpu20"
var(59) = 1

;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu21"
trigger2 = command = "cpu22"
trigger3 = command = "cpu23"
trigger4 = command = "cpu24"
trigger5 = command = "cpu25"
trigger6 = command = "cpu26"
trigger7 = command = "cpu27"
trigger8 = command = "cpu28"
trigger9 = command = "cpu29"
trigger10 = command = "cpu30"
var(59) = 1


;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu31"
trigger2 = command = "cpu32"
trigger3 = command = "cpu33"
trigger4 = command = "cpu34"
trigger5 = command = "cpu35"
trigger6 = command = "cpu36"
trigger7 = command = "cpu37"
trigger8 = command = "cpu38"
trigger9 = command = "cpu39"
trigger10 = command = "cpu40"
var(59) = 1

;------------------------------------------------------------------
[State -1,AI]
type = Varset
triggerall = var(59) != 1
trigger1 = command = "cpu41"
trigger2 = command = "cpu42"
trigger3 = command = "cpu43"
trigger4 = command = "cpu44"
trigger5 = command = "cpu45"
trigger6 = command = "cpu46"
trigger7 = command = "cpu47"
trigger8 = command = "cpu48"
trigger9 = command = "cpu49"
trigger10 = command = "cpu50"
var(59) = 1
;---------------------------------------------------------------------------

[State -1,AI]
type = Varset
triggerall = var(59)
triggerall = time = 1
trigger1 = p2life <= 0
trigger2 = life <= 0
var(59) = 0


[State -1,AI]
type = Varset
triggerall = var(59)
trigger1 = !Var(56)
var(56) = 1

[state -1,Mode Set]
type = VarSet
triggerall = !var(59)
trigger1 = command = "holds"
trigger1 = command = "x" && command = "y"
var(56) = 0


[state -1,Mode Set]
type = VarSet
triggerall = !var(59)
trigger1 = command = "holds"
trigger1 = command = "a" && command = "b"
var(56) = 1


[state -1,Mode Set]
type = VarSet
triggerall = !var(59)
trigger1 = command = "holds"
trigger1 = command = "z" && command = "c"
var(56) = 4


;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
[State -1, Taunt]
type = null;ChangeState
value = 195
triggerall = Var(59)
triggerall = ctrl
triggerall = StateType = S
triggerall = random <= 100
trigger1 = p2statetype = L

;---------------------------------------------------------------------------
[State -1, Oiuchi]
type = null;ChangeState
value = 430
triggerall = Var(59)
triggerall = p2bodydist x < 70
triggerall = random <= 300
triggerall = ctrl 
triggerall = StateType = S
trigger1 = p2statetype = L


;---------------------------------------------------------------------------
[State -1, Special Reversal]
type = ChangeState
value = 1270
triggerall = Var(59)
triggerall = var(56) > 1
triggerall = p2movetype = A
triggerall = statetype = S || statetype = C
trigger1 = ctrl
trigger1 = enemynear, hitdefattr = SCA, NA, SA, HA, AA,AP, NT, ST,HT, NP, SP, HP
trigger1 = p2bodydist X <= 80
trigger1 = random < 300


;---------------------------------------------------------------------------
;Escape

[State -1]
type = ChangeState
triggerall = var(59) && Stateno != [700,701]
triggerall = p2bodydist x < 100
triggerall = movetype != A
triggerall = p2stateno != 0
triggerall = StateType != A
trigger1 = p2stateno = var(43)
trigger2 = p2stateno = var(44)
trigger3 = p2stateno = var(45)
trigger4 = p2stateno = var(46)
trigger5 = p2stateno = var(47)
trigger6 = p2stateno = var(48)
trigger7 = p2stateno = var(49)
value = 7800 + (backedgedist > 100)


;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 720;ifelse(FrontEdgeDist < 90,720,720)
triggerall = numenemy > 1
triggerall = enemynear(0),life > 0 && enemynear(1),life > 0
triggerall = Var(59)
triggerall = var(57) = 0
triggerall = statetype = S
triggerall = ctrl
triggerall = random < 700
trigger1 = screenpos x = [enemynear(0),screenpos x,enemynear(1),screenpos x]
trigger2 = screenpos x = [enemynear(1),screenpos x,enemynear(0),screenpos x]

;---------------------------------------------------------------------------
[State -1]
type = ChangeState
value = 105
triggerall = numenemy < 2
triggerall = Var(59)
triggerall = BackEdgeDist > 90
triggerall = stateno != 105
triggerall = p2bodydist x < 100
triggerall = ctrl
triggerall = StateType != A
trigger1 = p2statetype = L && random < 300

;---------------------------------------------------------------------------
[State -1,AI run fwd]
type = ChangeState
value = 100
triggerall = var(59)
triggerall = stateno != 100
triggerall = statetype != A
triggerall = !inguarddist
trigger1 = ctrl
trigger1 = p2movetype != A
trigger1 = p2bodydist X > 100
trigger1 = random <= 50
;trigger2 = (var(17) = [1,2]) && Movehit
;trigger2 = p2bodydist X > 50

;---------------------------------------------------------------------------
[State -1,AI run back]
type = ChangeState
value = 105
triggerall = var(59)
triggerall = stateno != 105
triggerall = backedgedist > 70
triggerall = statetype != A
trigger1 = ctrl
trigger1 = p2movetype = A
trigger1 = p2bodydist X < 120
triggerall = random <= 200
;trigger2 = stateno = 512 && MoveGuarded


;---------------------------------------------------------------------------
[State -1,AI run fwd stop]
type = ChangeState
value = 0
triggerall = var(59)
triggerall = stateno = 100
trigger1 = p2movetype = A
trigger1 = p2bodydist X <= 105




;-------------------------------------------------------------------------------
;Guarding states

;---------------------------------------------------------------------------
[State -1,AI Guard]
type = ChangeState
triggerall = var(59) && Numenemy && (stateno != [120,155])
triggerall =!(enemynear,hitdefattr=SCA,AT)
;triggerall = statetype != A
triggerall = inguarddist
trigger1 = ctrl
value = 120

;-------------------------------------
[State -1, Stand Parry]
type = hitoverride
triggerall = var(56) > 1
triggerall = var(59) && roundstate = 2 && statetype = S
trigger1 = 1
attr = SAC, NA, SA, HA, NP, HP, SP, AA, AT, AP, NT,ST,HT
stateno = ifelse(random < 500,130, 1270)
slot = 0
time = ifelse((stateno=[150,153]),6,8)
;---------------------------------------------------------------------------

;-------------------------------------
[State -1, Crouch Parry]
type = hitoverride
triggerall = var(56) > 1
triggerall = var(59) && roundstate = 2 && statetype = C
trigger1 = 1
attr = C,NA, SA, HA, NP, HP, SP, AA, AT, AP,NT,ST,HT
stateno = ifelse(random < 500,131, 1270)
slot = 0
time = ifelse((stateno=[150,153]),6,8)
;---------------------------------------------------------------------------


;-------------------------------------
[State -1, Air Parry]
type = hitoverride
triggerall = var(56) > 1
triggerall = var(59) && roundstate = 2 && (statetype = A || Pos Y < 0)
trigger1 = 1
attr = SA,NA, SA, HA, NP, HP, SP, AA, AT, AP
stateno = 132
;forceair = 1
slot = 0
time = ifelse((stateno=[154,155]),6,8)



;-----------------------------------------------------------------------------
;Basic Attacks
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
[State -1, Follow Launcher]
type = ChangeState
value = 720
triggerall = Var(59)
triggerall = movehit
trigger1 = stateno = 410
;trigger2 = (enemynear,HitDefAttr = SCA,HA,HP,HT)
;trigger2 = ctrl


;---------------------------------------------------------------------------

[State -1, BodySlam]
type = ChangeState
value = 800
triggerall = var(59)
triggerall = p2bodydist X <= 30
triggerall = p2bodydist y = [-5,5]
triggerall = ctrl
triggerall = stateno != 100
trigger1 = statetype = S
trigger1 = random < 100


;---------------------------------------------------------------------------

[State -1, Flying Air Slam]
type = ChangeState
value = 830
triggerall = var(59)
triggerall = p2bodydist X <= 30
triggerall = p2bodydist y = [-5,5]
triggerall = ctrl
triggerall = stateno != 100
trigger1 = statetype = A
trigger1 = random < 100
;---------------------------------------------------------------------------
[State -1, Air Slam]
type = ChangeState
value = 860
triggerall = var(59)
triggerall = p2bodydist X <= 30
triggerall = p2bodydist y = [-5,5]
triggerall = ctrl
triggerall = stateno != 100
trigger1 = statetype = S
trigger1 = random < 100

;---------------------------------------------------------------------------
[State -1,AI standing light punch]
type = ChangeState
value = 200
triggerall = var(59)
triggerall = p2bodydist X = [0,80]
triggerall =  -30 <= p2bodydist y <= -30+var(7)
;triggerall =  -100 <= p2bodydist y <= 5
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random < 500
trigger1 = p2statetype != A && p2statetype != L
trigger2 = var(17) = 1 && var(19) = var(36)
trigger2 = stateno != 200


;---------------------------------------------------------------------------
[State -1, Wing Blade]
type = ChangeState
value = 230
triggerall = var(59)
triggerall = statetype != A
;triggerall =  -80 <= p2bodydist y <= -80+var(7)
triggerall = p2bodydist X = [0,80]
trigger1 = p2bodydist y = [-5,5]
trigger1 = ctrl
trigger1 = random < 300
trigger1 = p2statetype != A && p2statetype != L
trigger2 = var(17) = 1 && var(19) = var(36)
trigger2 = stateno != 230


;---------------------------------------------------------------------------

[State -1, Crouch Punch]
type = ChangeState
value = 400
triggerall = var(59)
triggerall = p2bodydist X = [0,65]
;triggerall =  -60 <= p2bodydist y <= -60+var(7)
triggerall = p2bodydist y = [-5,5]
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random < 300
trigger1 = p2statetype != A && p2statetype != L
trigger2 = var(17) = 1 && var(19) = var(36)
trigger2 = stateno != 400

;---------------------------------------------------------------------------
[State -1,Wing Spiked Items]
type = ChangeState
value = 210
triggerall = var(59)
triggerall = statetype != A
;triggerall =  -80 <= p2bodydist y <= -80+var(7)
triggerall = p2bodydist X = [0,100]
trigger1 = p2bodydist y = [-55,5]
trigger1 = ctrl
trigger1 = random < 300
trigger1 = p2statetype != A && p2statetype != L
trigger2 = var(17) = 1 && var(19) = var(36)
trigger2 = stateno != 230



;---------------------------------------------------------------------------
[State -1,Bamboo Uppercut]
type = ChangeState
value = 410
triggerall = var(59)
triggerall = p2bodydist X = [0,20]
triggerall =  -50 <= p2bodydist y <= -30+var(7)
;triggerall =  -100 <= p2bodydist y <= 5
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random < 400
trigger1 = p2movetype != A && p2statetype != A && p2statetype != L
trigger2 = var(17) = 1 && random < 300
trigger3 = var(17) = 2 && var(20) = var(36)
trigger3 = stateno != 410
trigger4 = var(17) = 5 && stateno = 52 && random < 200


;---------------------------------------------------------------------------
[State -1, Crouch Kick]
type = ChangeState
value = 430
triggerall = var(59)
triggerall = statetype != A
triggerall = p2bodydist X = [0,80]
;triggerall =  -70 <= p2bodydist y <= -70+var(7)
triggerall = p2bodydist y = [-5,5]
trigger1 = p2statetype != L && ctrl  && random < 400 ; && p2movetype = H
trigger2 = var(17) = 1 && random < 200
trigger3 = var(17) = 2 && random < 300
trigger4 = var(17) = 3 && var(21) = var(36)
trigger4 = stateno != 440
;trigger5 = stateno = 420 && MoveHit
trigger5 = var(17) = 6 && stateno = 52 && random < 200
;---------------------------------------------------------------------------
[State -1, over head atk]
type = ChangeState
value = 590
triggerall = var(59)
triggerall = p2bodydist X = [4,70]
triggerall =  -40 <= p2bodydist y <= -40+var(7)
triggerall = statetype != A
trigger1 = ctrl
trigger1 = random < 100 + 100*(p2statetype = C)
trigger1 = p2movetype != A && p2statetype != A && p2statetype != L
trigger2 = var(17) = 1 && random < 100
trigger3 = var(17) = 2 && var(20) = var(36)
trigger3 = stateno != 590 && random < 200
trigger4 = var(17) = 5 && stateno = 52 && random < 200


;---------------------------------------------------------------------------
[State -1, Nurse WheelChair Push]
type = ChangeState
value = 300
triggerall = var(59)
triggerall = statetype != A
triggerall = p2bodydist X = [30,120]
triggerall = p2bodydist y = [-5,5]
;triggerall =  -40 <= p2bodydist y <= -10+var(7)
trigger1 = ctrl && p2movetype != A
trigger1 = p2statetype != L && random < 200
;trigger1 = enemynear,statetype != C
trigger2 = var(17) = 1 && random < 100
trigger3 = var(17) = 2 && random < 200
trigger4 = var(17) = 3 && var(21) = var(36)
trigger4 = stateno != 300
trigger5 = var(17) = 6 && stateno = 52 && random < 200
;trigger5 = (stateno = 520 || Stateno = 512) && MoveHit; && random < 300

;---------------------------------------------------------------------------
[State -1, Maid Mop Push]
type = ChangeState
value = 310
triggerall = var(59)
triggerall = statetype != A
triggerall = p2bodydist X = [30,120]
triggerall = p2bodydist y = [-5,5]
;triggerall =  -40 <= p2bodydist y <= -10+var(7)
trigger1 = ctrl && p2movetype != A
trigger1 = p2statetype != L && random < 200
;trigger1 = enemynear,statetype != C
trigger2 = var(17) = 1 && random < 100
trigger3 = var(17) = 2 && random < 200
trigger4 = var(17) = 3 && var(21) = var(36)
trigger4 = stateno != 310
trigger5 = var(17) = 6 && stateno = 52 && random < 200
;trigger5 = (stateno = 520 || Stateno = 512) && MoveHit; && random < 300



;-----------------------------------------------------------------------------
;AI Combo
;---------------------------------------------------------------------------
[State -1, Nurse hit w/Crutch or Waitress Hit w/Tray]
type = ChangeState
value = ifelse(random < 500,1000,1015)
triggerall = Var(59) && random < 500
trigger1 = Stateno = [200,999]
trigger1 = MoveContact
trigger1 = Statetype != A


;------------------------------------------------------------------------------
[State -1, Nurse hit w/Stand or Maid Mop PushFC]
type = ChangeState
value = ifelse(random < 500,1001,1010)
triggerall = Var(59) && random < 500
trigger1 = Stateno = 1000 ;Nurse hit w/Crutch
trigger1 = MoveContact
trigger1 = Statetype != A

;------------------------------------------------------------------------------
[State -1, Nurse WheelChair Push or Maid Pan SmashFC]
type = ChangeState
value = ifelse(random < 500,1002,ifelse(random < 500,1025,1240+10*(random%3)))
triggerall = Var(59) && random < 500
trigger1 = MoveContact
trigger1 = stateno = 1001
trigger2 = hitcount > 1 || moveguarded > 1
trigger2 = stateno = 1010



;---------------------------------------------------------------------------
[State -1, Waitress Spill Tray or Kimono Hit w/Fan]
type = ChangeState
value = ifelse(random < 500,1020,1030)
triggerall = Var(59) && random < 500
trigger1 = stateno = 1015 ;Waitress Hit w/Tray
trigger1 = MoveContact
trigger1 = Statetype != A


;---------------------------------------------------------------------------
[State -1, Waitress Hit w/Cash Register or Grab To FireWork]
type = ChangeState
value = ifelse(random < 500,1022,901)
triggerall = Var(59) && random < 500
trigger1 = stateno = 1020
trigger1 = movecontact
trigger2 = stateno = 1030
trigger2 = hitcount > 1 || moveguarded > 1




;---------------------------------------------------------------------------
;----|AI Specials |---------------------------------------------------


;---------------------------------------------------------------------------
[State -1, Spinning Wing Slash 1 or 2 or 3]
type = ChangeState
value = 2080+(power > 500)+(power>1000)
triggerall = var(59)
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = p2bodydist X = [20,100]
;triggerall = p2bodydist Y = [-40,5]
triggerall =  -40 <= p2bodydist y <= -40+var(7)
triggerall = random < 100
trigger1 = ctrl
trigger2 = var(17) = 3
trigger3 = var(9)

;---------------------------------------------------------------------------
[State -1, Shadow Blade 1 or 2 or 3]
type = ChangeState
value = 2040+(power > 500)+(power>1000)
triggerall = var(59)
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = p2bodydist X = [0,80]
;triggerall = p2bodydist Y = [-40,5]
triggerall =  -40 <= p2bodydist y <= -40+var(7)
triggerall = random < 100
trigger1 = ctrl
trigger2 = var(17) = 3
trigger3 = var(9)


;---------------------------------------------------------------------------
[State -1, Air Fire Bat Level 1 or 2 or 3]
type = ChangeState
value = 2010+(power > 500)+(power>1000)
triggerall = var(59)
triggerall = statetype = A
triggerall = p2statetype != L
triggerall = p2bodydist X > 70
triggerall = p2bodydist Y = [70,340]
triggerall = p2bodydist Y/p2bodydist X = [0.7,1.3]
;triggerall =  -100 <= p2bodydist y <= -60+var(7)
triggerall = random < 100
trigger1 = ctrl
trigger2 = var(17) = 3
trigger3 = var(9)

;---------------------------------------------------------------------------
[State -1, Fire Bat Level 1 or 2 or 3]
type = ChangeState
value = 2000+(power > 500)+(power>1000)
triggerall = var(59)
triggerall = statetype != A
triggerall = p2statetype != L
triggerall = p2bodydist X = [70,270]
;triggerall = p2bodydist Y = [-40,5]
triggerall =  -40 <= p2bodydist y <= -40+var(7)
triggerall = random < 100
trigger1 = ctrl
trigger2 = var(17) = 3
trigger3 = var(9)

;---------------------------------------------------------------------------
[State -1, Jump in]
type = ChangeState
value = ifelse(random < 500,100,631)
triggerall = stateno != 100 || stateno != 631
triggerall = var(59)
trigger1 = p2bodydist X = [120,270]
trigger1 = statetype != A && p2statetype != L
trigger1 = ctrl
trigger1 = random < 100


;------------------------------------------------------------------------------



;----|AI Hypers |---------------------------------------------------

;------------------------------------------------------------------------------


;-------------------------------------------------------------------------

[State -1,Super Wing Slash]
type = ChangeState
value = 3000
triggerall = Var(59) && (stateno != [3000,3500]) 
triggerall = power >= 1000
triggerall = statetype != A
triggerall = p2bodydist X = [0,80]
triggerall = p2bodydist y = [-45,5]
triggerall = random < 100; + 100*(enemynear,movetype, = H)
;triggerall = p2statetype != L && p2stateno != 5120
trigger1 = ctrl
trigger2 = random < (var(17)*100)
trigger3 = var(51) && random < 100+100*(var(9) > 0)

;---------------------------------------------------------------------------

[State -1,Lillith Team Up Attack]
type = ChangeState
value = 3040
triggerall = Var(59) && (stateno != [3000,3500]) 
triggerall = power >= 1000
triggerall = statetype != A
triggerall = p2bodydist X = [70,270]
triggerall = p2bodydist y = [-5,5]
triggerall = random < 100; + 100*(enemynear,movetype, = H)
;triggerall = p2statetype != L && p2stateno != 5120
trigger1 = ctrl
trigger2 = random < (var(17)*100)
trigger3 = var(51) && random < 100+100*(var(9) > 0)


;---------------------------------------------------------------------------

[State -1, Death Blade]
type = ChangeState
value = 3080
triggerall = NumHelper(3002) = 0
triggerall = Var(59) && (stateno != [3000,3500]) 
triggerall = power >= 1000
triggerall = statetype != A
triggerall = p2bodydist X = [70,270]
triggerall = p2bodydist y = [-45,5]
triggerall = random < 100; + 100*(enemynear,movetype, = H)
;triggerall = p2statetype != L && p2stateno != 5120
trigger1 = ctrl
trigger2 = random < (var(17)*100)
trigger3 = var(51) && random < 100+100*(var(9) > 0)



;---------------------------------------------------------------------------
[State -1, Easy Reversal]
type = ChangeState
value = 2017
triggerall = Var(59)
triggerall = ctrl && random < 50
trigger1 = stateno = 5120
trigger2 = statetype = S
trigger2 = power > 1000
trigger2 = p2bodydist X <= 50

;---------------------------------------------------------------------------
[State -1, Rolling Crush]
type = ChangeState
value = 1210
triggerall = stateno != [720,721]
triggerall = Var(59)
triggerall = power >= 1000
trigger1 = ctrl 
trigger1 = random < 10



;------------------------------------------------------------------------------------------------------
[State -1, Jumping Spike]
type = ChangeState
value = 600
triggerall = var(59)
trigger1 = p2bodydist X = [0,50]
trigger1 = statetype = A && ctrl
;trigger1 =  -80 <= p2bodydist y <= -80+var(7)
trigger1 = var(8) = [-20,15] ;&& p2statetype = A
trigger1 = random < 400
trigger2 = var(17) = 5 && var(19) = var(36)
trigger2 = stateno != 600


;---------------------------------------------------------------------------
[State -1, Jump Kick]
type = ChangeState
value = 630
triggerall = var(59)
trigger1 = statetype = A && ctrl && random < 300
trigger1 = var(8) = [-20,15]
;trigger1 =  -80 <= p2bodydist y <= -80+var(7)
trigger1 = p2bodydist X = [0,50]
trigger2 = var(17) = 5 && var(19) = var(36) && random < 300
trigger2 = stateno != 630



;---------------------------------------------------------------------------
[State -1, Air Drill Attack]
type = ChangeState
value = 640
triggerall = var(59)
;triggerall =  -30 <= p2bodydist y <= -30+var(7)
triggerall = var(8) = [-20,15]
triggerall = p2bodydist X = [0,70]
trigger1 = statetype = A && ctrl && random < 200
trigger2 = var(17) = 5 && random < 300
trigger3 = var(17) = 6 && var(20) = var(36)
trigger3 = stateno != 710






;---------------------------------------------------------------------------
[State -1, Down Kick]
type = ChangeState
value = 8018
triggerall = Var(59); && !var(54)
triggerall = stateno != [720,721]
triggerall = StateType = A
triggerall = Ctrl
triggerall = Vel Y > 2
triggerall = Pos Y < -170
trigger1 = random < 200
trigger1 = ctrl




;---------------------------------------------------------------------------








;---------------------------------------------------------------------------

[State -1,Super Wing Slash]
type = ChangeState
value = 3000
triggerall = command = "Super Wing Slash"
triggerall = power >= 1000
triggerall = statetype = S || statetype = C
trigger1 = ctrl


;---------------------------------------------------------------------------

[State -1, Lillith Team Up Attack]
type = ChangeState
value = 3040
triggerall = command = "Lillith Team Up Attack"
triggerall = power >= 1000
triggerall = statetype = S || statetype = C
trigger1 = ctrl
;------------------------------------------------------------------------------
[State -1, Death Blade]
type = ChangeState
value = 3080
triggerall = command = "Death Blade"
triggerall = power >= 1000
triggerall = statetype = S || statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, Fire Bat Level 1]
type = ChangeState
value = 2000
triggerall = command = "QCF_x"
trigger1 = ctrl
trigger1 = statetype = S || statetype = C

;---------------------------------------------------------------------------
[State -1, Fire Bat Level 2]
type = ChangeState
value = 2001
triggerall = command = "QCF_y"
triggerall = power >= 500
trigger1 = ctrl
trigger1 = statetype = S || statetype = C

;---------------------------------------------------------------------------
[State -1,Fire Bat Level 3]
type = ChangeState
value = 2002
triggerall = command = "QCF_z"
triggerall = power >= 1000
trigger1 = ctrl
trigger1 = statetype = S || statetype = C


;---------------------------------------------------------------------------
[State -1, Air Fire Bat Level 1]
type = ChangeState
value = 2010
triggerall = command = "QCF_x"
trigger1 = ctrl
trigger1 = statetype = A

;---------------------------------------------------------------------------
[State -1, Air Fire Bat Level 2]
type = ChangeState
value = 2011
triggerall = command = "QCF_y"
triggerall = power >= 500
trigger1 = ctrl
trigger1 = statetype = A

;---------------------------------------------------------------------------
[State -1, Air Fire Bat Level 3]
type = ChangeState
value = 2012
triggerall = command = "QCF_z"
triggerall = power >= 1000
trigger1 = ctrl
trigger1 = statetype = A

;---------------------------------------------------------------------------
[State -1, Shadow Blade Level 1]
type = ChangeState
value = 2040
triggerall = command = "QCF_a"
triggerall = ctrl
trigger1 = statetype = S || statetype = C

;---------------------------------------------------------------------------
[State -1, Shadow Blade Level 2]
type = ChangeState
value = 2041
triggerall = command = "QCF_b"
triggerall = power >= 500
triggerall = ctrl
trigger1 = statetype = S || statetype = C

;---------------------------------------------------------------------------
[State -1, Shadow Blade Level 3]
type = ChangeState
value = 2042
triggerall = command = "QCF_c"
triggerall = power >= 1000
triggerall = ctrl
trigger1 = statetype = S || statetype = C


;---------------------------------------------------------------------------
[State -1, Spinning Wing Slash 1]
type = ChangeState
value = 2080
triggerall = command = "QCB_x"
trigger1 = statetype = S || statetype = C
trigger1 = ctrl


;---------------------------------------------------------------------------
[State -1, Spinning Wing Slash 2]
type = ChangeState
value = 2081
triggerall = command = "QCB_y"
triggerall = power >= 500
trigger1 = statetype = S || statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, Spinning Wing Slash 3]
type = ChangeState
value = 2082
triggerall = command = "QCB_z"
triggerall = power >= 1000
trigger1 = statetype = S || statetype = C
trigger1 = ctrl




;---------------------------------------------------------------------------
[State -1, Nurse hit w/Crutch]
type = ChangeState
value = 1000
trigger1 = command = "x"
trigger1 = Stateno = 200
trigger1 = MoveContact
;trigger1 = Time = 10

;------------------------------------------------------------------------------
[State -1, Nurse hit w/Stand]
type = ChangeState
value = 1001
trigger1 = command = "x"
trigger1 = Stateno = 1000
trigger1 = MoveContact
trigger1 = Time >= 10

;------------------------------------------------------------------------------
[State -1, Nurse WheelChair Push]
type = ChangeState
value = 1002
triggerall= command = "x"
triggerall = Time >= 10
trigger1 = MoveContact
trigger1 = stateno = 1001
trigger2 = hitcount > 1 || moveguarded > 1
trigger2 = stateno = 1010

;---------------------------------------------------------------------------
[State -1, Maid Mop PushFC]
type = ChangeState
value = 1010
trigger1 = stateno = 1000
trigger1 = MoveContact
trigger1 = command = "y"
trigger1 = time >= 10

;---------------------------------------------------------------------------
[State -1, Waitress Hit w/Tray]
type = ChangeState
value = 1015
trigger1 = stateno = 200
trigger1 = MoveContact
trigger1 = command = "y"
;trigger1 = time >= 10

;---------------------------------------------------------------------------
[State -1, Waitress Spill Tray]
type = ChangeState
value = 1020
trigger1 = stateno = 1015
trigger1 = MoveContact
trigger1 = command = "y"
trigger1 = time >= 10


;---------------------------------------------------------------------------
[State -1, Waitress Hit w/Cash Register]
type = ChangeState
value = 1022
triggerall = command = "y"
triggerall = time >= 10
trigger1 = stateno = 1020
trigger1 = movecontact
trigger2 = stateno = 1030
trigger2 = hitcount > 1 || moveguarded > 1

;---------------------------------------------------------------------------


[State -1, Grab To FireWork]
type = ChangeState
value = 901
triggerall = command = "x"
triggerall = time >= 10
trigger1 = stateno = 1020
trigger1 = movecontact
trigger2 = stateno = 1030
trigger2 = hitcount > 1 || moveguarded > 1

;---------------------------------------------------------------------------
[State -1, Maid Pan SmashFC]
type = ChangeState
value = 1025
triggerall = command = "y"
triggerall = Time >= 10
trigger1 = MoveContact
trigger1 = stateno = 1001
trigger2 = hitcount > 1 || moveguarded > 1
trigger2 = stateno = 1010


;---------------------------------------------------------------------------
[State -1, Kimono Hit w/Fan]
type = ChangeState
value = 1030
trigger1 = stateno = 1015
trigger1 = MoveContact
trigger1 = command = "x"
trigger1 = time >= 10


;---------------------------------------------------------------------------
[State -1, Maid Pan Smash]
type = ChangeState
value = 1240
trigger1 = command = "z"
trigger1 = command != "holdback"
trigger1 = command != "holdfwd"
trigger1 = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1, Nurse Needle]
type = ChangeState
value = 1250
triggerall = command = "z"
triggerall = ctrl
trigger1 = statetype = S
trigger1 = (command = "holdfwd") || (command = "holdback")
;---------------------------------------------------------------------------
[State -1, Golf Club Swing]
type = ChangeState
value = 1260
triggerall = command = "z"
triggerall = command = "holddown"
triggerall = command != "holdfwd"
triggerall = command != "holdback"
triggerall = ctrl
trigger1 = statetype = C


;---------------------------------------------------------------------------




;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command != "holdc"
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command != "holdc"
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl



;---------------------------------------------------------------------------
;Air Dash
[State -1, Air Dash]
type = ChangeState
value = 715
trigger1 = command = "holdc"
trigger1 = stateno = 100
trigger1 = statetype = S
trigger1 = ctrl
;---------------------------------------------------------------------------

[State -1,BodySlam]
type = ChangeState
value = 800
triggerall = command = "Stand Throw"
triggerall = !MoveGuarded
triggerall = ctrl
triggerall = stateno != 100
trigger1 = statetype = S
;---------------------------------------------------------------------------

[State -1, Flying Air Slam]
type = ChangeState
value = 830
triggerall = command = "Air Throw"
triggerall = !MoveGuarded
triggerall = ctrl
trigger1 = stateno != 100
trigger1 = statetype = A

;---------------------------------------------------------------------------
[State -1, Air Slam]
type = ChangeState
value = 860
triggerall = command = "special throw"
triggerall = !MoveGuarded
triggerall = ctrl
triggerall = stateno != 100
trigger1 = statetype = S


;---------------------------------------------------------------------------

[State -1, FireWork]
type = ChangeState
value = 901
trigger1 = command = "FireWork"
trigger1 = ctrl
triggerall = stateno != 100
trigger1 = statetype = S

;---------------------------------------------------------------------------

;===========================================================================
;---------------------------------------------------------------------------
[State -1, Drill Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holdfwd"
triggerall = stateno != 100
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1, Wing Spiked Items]
type = ChangeState
value = 210
triggerall = command = "x"
triggerall = command = "holdfwd"
triggerall = stateno != 100
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1, Wing Blade]
type = ChangeState
value = 230
triggerall = command = "y"
triggerall = stateno != 100
triggerall = ctrl
trigger1 = statetype = S

;---------------------------------------------------------------------------
[State -1,  Nurse WheelChair Push]
type = ChangeState
value = 300
triggerall = ctrl
triggerall = statetype = S
trigger1 = command = "FFx"
trigger2 = command = "x"
trigger2 = stateno = 100

;---------------------------------------------------------------------------
[State -1, Maid Mop Push]
type = ChangeState
value = 310
triggerall = ctrl
triggerall = statetype = S
trigger1 = command = "FFy"
trigger2 = command = "y"
trigger2 = stateno = 100
;---------------------------------------------------------------------------
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = !Var(59)
triggerall = command = "start"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------

[State -1, Crouch Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command != "holdfwd"
triggerall = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
[State -1, Bamboo Uppercut]
type = ChangeState
value = 410
triggerall = command = "x"
triggerall = command = "holdfwd"
triggerall = ctrl
trigger1 = statetype = C

;---------------------------------------------------------------------------
[State -1, Crouch Kick]
type = ChangeState
value = 430
triggerall = command = "y"
triggerall = ctrl
trigger1 = statetype = C

;--------------------------------------------------------------------------------
[State -1, Jumping Spike]
type = ChangeState
value = 600
triggerall = command = "x"
triggerall = ctrl
trigger1 = statetype = A


;---------------------------------------------------------------------------
[State -1, Jump Kick]
type = ChangeState
value = 630
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = ctrl
trigger1 = statetype = A


;---------------------------------------------------------------------------
[State -1, Air Drill Attack]
type = ChangeState
value = 640
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = ctrl
trigger1 = statetype = A

;---------------------------------------------------------------------------
[State -1, Roll recovery foward]
type = ChangeState
value = 700
triggerall = stateno = 5120
trigger1 = command = "holdfwd"
trigger1 = Time = 1

;---------------------------------------------------------------------------
[State -1, Roll recovery Backward]
type = ChangeState
value = 701
triggerall = stateno = 5120
trigger1 = command = "holdback"
trigger1 = Time = 1


;---------------------------------------------------------------------------
[State -1, Oiuchi]
type = ChangeState
value = 704
triggerall = p2stateno = 5110
triggerall = command = "Oiuchi"
trigger1 = ctrl 
trigger1 = StateType = S



;---------------------------------------------------------------------------
[State -1, Rolling Crush]
type = ChangeState
value = 1210
triggerall = command = "Rolling Crush"
triggerall = power >= 1000
trigger1 = ctrl 


;---------------------------------------------------------------------------
[State -1, Mega Crush]
type = ChangeState
value = 1230
triggerall = command = "Mega Crush"
triggerall = power >= 1000
trigger1 = ctrl 


;---------------------------------------------------------------------------
[State -1, Easy Reversal]
type = ChangeState
value = 2017
trigger1 = stateno = 5120
trigger1 = command = "a"
trigger1 = Time = 1


;---------------------------------------------------------------------------
[State -1, Special Reversal]
type = ChangeState
value = 1270
triggerall = command = "Special Reversal"
trigger1 = ctrl
trigger1 = statetype = S || statetype = C




;---------------------------------------------------------------------------
[State -1, Super Jump]
type = ChangeState
value = 710
triggerall = statetype != A
trigger1 = command = "Super Jump"
trigger1 = ctrl
trigger2 = command = "Super Jump" || command = "holdup"
trigger2 = MoveHit
trigger2 = stateno = 410



